@@ -15,3 +15,7 @@ def py_src_dir(app_dir: Path, app_name: str) -> Path:
 
 def runtime_dir(app_dir: Path, app_name: str) -> Path:
     return py_src_dir(app_dir, app_name) / "runtime"
+
+
+def ts_root_dir(app_dir: Path) -> Path:
+    return clients_root_dir(app_dir) / "ts"
